==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        bc() {
            return new SlowStochasticOscillatorIndicator();
        }
        get_y0() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.zm));
        }
        set zl(a) {
            this.h(SlowStochasticOscillatorIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.zm = StrategyBasedIndicator.zi(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();

==> igniteui-angular-charts-18.0.0.tgz: package/esm2015/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let SlowStochasticOscillatorIndicator = /*@__PURE__*/ (() => {
    class SlowStochasticOscillatorIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 3;
        }
        bb() {
            return new SlowStochasticOscillatorIndicator();
        }
        get_aaa() {
            return new SlowStochasticOscillatorIndicatorStrategy();
        }
        get aaa() {
            return this.get_aaa();
        }
        get_aan() {
            return SlowStochasticOscillatorIndicator.$;
        }
        get aan() {
            return this.get_aan();
        }
        get aav() {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.aaw));
        }
        set aav(a) {
            this.h(SlowStochasticOscillatorIndicator.aaw, a);
        }
        aag() {
            return this.aav;
        }
        aap(a) {
            this.aav = a;
        }
    }
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.aaw = StrategyBasedIndicator.aas(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
})();
